from _typeshed import Incomplete

def is_tournament(G): ...
def hamiltonian_path(G): ...
def random_tournament(n, seed: Incomplete | None = None): ...
def score_sequence(G): ...
def is_reachable(G, s, t): ...
def is_strongly_connected(G): ...
