from _typeshed import Incomplete

def projected_graph(B, nodes, multigraph: bool = False): ...
def weighted_projected_graph(B, nodes, ratio: bool = False): ...
def collaboration_weighted_projected_graph(B, nodes): ...
def overlap_weighted_projected_graph(B, nodes, jaccard: bool = True): ...
def generic_weighted_projected_graph(B, nodes, weight_function: Incomplete | None = None): ...
