from _typeshed import ReadableBuffer

class Error(Exception): ...

def ZSTD_compress(__data: ReadableBuffer, __level: int = ..., __threads: int = ...) -> bytes: ...
def ZSTD_external() -> int: ...
def ZSTD_uncompress(__data: ReadableBuffer) -> bytes: ...
def ZSTD_version() -> str: ...
def ZSTD_version_number() -> int: ...
def ZSTD_threads_count() -> int: ...
def ZSTD_max_threads_count() -> int: ...
def compress(__data: ReadableBuffer, __level: int = ..., __threads: int = ...) -> bytes: ...
def decompress(__data: ReadableBuffer) -> bytes: ...
def dumps(__data: ReadableBuffer, __level: int = ..., __threads: int = ...) -> bytes: ...
def loads(__data: ReadableBuffer) -> bytes: ...
def uncompress(__data: ReadableBuffer) -> bytes: ...
def version() -> str: ...
