from _typeshed import Incomplete

string_types: Incomplete

def is_executable_file(path): ...
def which(filename, env: Incomplete | None = None): ...
def split_command_line(command_line): ...
def select_ignore_interrupts(iwtd, owtd, ewtd, timeout: Incomplete | None = None): ...
def poll_ignore_interrupts(fds, timeout: Incomplete | None = None): ...
