from _typeshed import Incomplete

def cut_size(G, S, T: Incomplete | None = None, weight: Incomplete | None = None): ...
def volume(G, S, weight: Incomplete | None = None): ...
def normalized_cut_size(G, S, T: Incomplete | None = None, weight: Incomplete | None = None): ...
def conductance(G, S, T: Incomplete | None = None, weight: Incomplete | None = None): ...
def edge_expansion(G, S, T: Incomplete | None = None, weight: Incomplete | None = None): ...
def mixing_expansion(G, S, T: Incomplete | None = None, weight: Incomplete | None = None): ...
def node_expansion(G, S): ...
def boundary_expansion(G, S): ...
