from _typeshed import Incomplete

def effective_size(G, nodes: Incomplete | None = None, weight: Incomplete | None = None): ...
def constraint(G, nodes: Incomplete | None = None, weight: Incomplete | None = None): ...
def local_constraint(G, u, v, weight: Incomplete | None = None): ...
