from _typeshed import Incomplete

def local_node_connectivity(G, source, target, cutoff: Incomplete | None = None): ...
def node_connectivity(G, s: Incomplete | None = None, t: Incomplete | None = None): ...
def all_pairs_node_connectivity(G, nbunch: Incomplete | None = None, cutoff: Incomplete | None = None): ...
