from _typeshed import Incomplete

def node_link_data(
    G,
    attrs: Incomplete | None = None,
    *,
    source: str = "source",
    target: str = "target",
    name: str = "id",
    key: str = "key",
    link: str = "links",
): ...
def node_link_graph(
    data,
    directed: bool = False,
    multigraph: bool = True,
    attrs: Incomplete | None = None,
    *,
    source: str = "source",
    target: str = "target",
    name: str = "id",
    key: str = "key",
    link: str = "links",
): ...
