from _typeshed import Incomplete

def laplacian_spectrum(G, weight: str = "weight"): ...
def normalized_laplacian_spectrum(G, weight: str = "weight"): ...
def adjacency_spectrum(G, weight: str = "weight"): ...
def modularity_spectrum(G): ...
def bethe_hessian_spectrum(G, r: Incomplete | None = None): ...
