def trophic_levels(G, weight: str = "weight"): ...
def trophic_differences(G, weight: str = "weight"): ...
def trophic_incoherence_parameter(G, weight: str = "weight", cannibalism: bool = False): ...
