from _typeshed import Incomplete

def triangles(G, nodes: Incomplete | None = None): ...
def average_clustering(G, nodes: Incomplete | None = None, weight: Incomplete | None = None, count_zeros: bool = True): ...
def clustering(G, nodes: Incomplete | None = None, weight: Incomplete | None = None): ...
def transitivity(G): ...
def square_clustering(G, nodes: Incomplete | None = None): ...
def generalized_degree(G, nodes: Incomplete | None = None): ...
