from _typeshed import Incomplete
from collections.abc import Generator

def connected_components(G) -> Generator[Incomplete, None, None]: ...
def number_connected_components(G): ...
def is_connected(G): ...
def node_connected_component(G, n): ...
