from _typeshed import Incomplete
from collections.abc import Generator

def is_biconnected(G): ...
def biconnected_component_edges(G) -> Generator[Incomplete, Incomplete, None]: ...
def biconnected_components(G) -> Generator[Incomplete, None, None]: ...
def articulation_points(G) -> Generator[Incomplete, None, None]: ...
