from _typeshed import Incomplete

def current_flow_betweenness_centrality_subset(
    G, sources, targets, normalized: bool = True, weight: Incomplete | None = None, dtype=..., solver: str = "lu"
): ...
def edge_current_flow_betweenness_centrality_subset(
    G, sources, targets, normalized: bool = True, weight: Incomplete | None = None, dtype=..., solver: str = "lu"
): ...
