from _typeshed import Incomplete

def color(G): ...
def is_bipartite(G): ...
def is_bipartite_node_set(G, nodes): ...
def sets(G, top_nodes: Incomplete | None = None): ...
def density(B, nodes): ...
def degrees(B, nodes, weight: Incomplete | None = None): ...
