from _typeshed import Incomplete

def core_number(G): ...
def k_core(G, k: Incomplete | None = None, core_number: Incomplete | None = None): ...
def k_shell(G, k: Incomplete | None = None, core_number: Incomplete | None = None): ...
def k_crust(G, k: Incomplete | None = None, core_number: Incomplete | None = None): ...
def k_corona(G, k, core_number: Incomplete | None = None): ...
def k_truss(G, k): ...
def onion_layers(G): ...
