from _typeshed import Incomplete

def grid_2d_graph(m, n, periodic: bool = False, create_using: Incomplete | None = None): ...
def grid_graph(dim, periodic: bool = False): ...
def hypercube_graph(n): ...
def triangular_lattice_graph(
    m, n, periodic: bool = False, with_positions: bool = True, create_using: Incomplete | None = None
): ...
def hexagonal_lattice_graph(
    m, n, periodic: bool = False, with_positions: bool = True, create_using: Incomplete | None = None
): ...
