from _typeshed import Incomplete

def modularity_matrix(G, nodelist: Incomplete | None = None, weight: Incomplete | None = None): ...
def directed_modularity_matrix(G, nodelist: Incomplete | None = None, weight: Incomplete | None = None): ...
