from _typeshed import Incomplete
from collections.abc import Generator

def attracting_components(G) -> Generator[Incomplete, None, None]: ...
def number_attracting_components(G): ...
def is_attracting_component(G): ...
