from _typeshed import Incomplete
from collections.abc import Generator

def asyn_lpa_communities(
    G, weight: Incomplete | None = None, seed: Incomplete | None = None
) -> Generator[Incomplete, Incomplete, None]: ...
def label_propagation_communities(G): ...
