from _typeshed import Incomplete
from collections.abc import Generator

def triadic_census(G, nodelist: Incomplete | None = None): ...
def is_triad(G): ...
def all_triplets(G): ...
def all_triads(G) -> Generator[Incomplete, None, None]: ...
def triads_by_type(G): ...
def triad_type(G): ...
def random_triad(G, seed: Incomplete | None = None): ...
