from _typeshed import Incomplete

def resource_allocation_index(G, ebunch: Incomplete | None = None): ...
def jaccard_coefficient(G, ebunch: Incomplete | None = None): ...
def adamic_adar_index(G, ebunch: Incomplete | None = None): ...
def common_neighbor_centrality(G, ebunch: Incomplete | None = None, alpha: float = 0.8): ...
def preferential_attachment(G, ebunch: Incomplete | None = None): ...
def cn_soundarajan_hopcroft(G, ebunch: Incomplete | None = None, community: str = "community"): ...
def ra_index_soundarajan_hopcroft(G, ebunch: Incomplete | None = None, community: str = "community"): ...
def within_inter_cluster(G, ebunch: Incomplete | None = None, delta: float = 0.001, community: str = "community"): ...
