from _typeshed import Incomplete

def is_valid_joint_degree(joint_degrees): ...
def joint_degree_graph(joint_degrees, seed: Incomplete | None = None): ...
def is_valid_directed_joint_degree(in_degrees, out_degrees, nkk): ...
def directed_joint_degree_graph(in_degrees, out_degrees, nkk, seed: Incomplete | None = None): ...
