from _typeshed import Incomplete

def uniform_random_intersection_graph(n, m, p, seed: Incomplete | None = None): ...
def k_random_intersection_graph(n, m, k, seed: Incomplete | None = None): ...
def general_random_intersection_graph(n, m, p, seed: Incomplete | None = None): ...
