from _typeshed import Incomplete

def astar_path(G, source, target, heuristic: Incomplete | None = None, weight: str = "weight"): ...
def astar_path_length(G, source, target, heuristic: Incomplete | None = None, weight: str = "weight"): ...
