from _typeshed import Incomplete

def betweenness_centrality(
    G,
    k: Incomplete | None = None,
    normalized: bool = True,
    weight: Incomplete | None = None,
    endpoints: bool = False,
    seed: Incomplete | None = None,
): ...
def edge_betweenness_centrality(
    G, k: Incomplete | None = None, normalized: bool = True, weight: Incomplete | None = None, seed: Incomplete | None = None
): ...
