from _typeshed import Incomplete

def write_dot(G, path) -> None: ...
def read_dot(path): ...
def from_pydot(P): ...
def to_pydot(N): ...
def graphviz_layout(G, prog: str = "neato", root: Incomplete | None = None): ...
def pydot_layout(G, prog: str = "neato", root: Incomplete | None = None): ...
