from _typeshed import Incomplete
from collections.abc import Generator

def nonisomorphic_trees(order, create: str = "graph") -> Generator[Incomplete, None, None]: ...
def number_of_nonisomorphic_trees(order): ...
