def maximal_matching(G): ...
def is_matching(G, matching): ...
def is_maximal_matching(G, matching): ...
def is_perfect_matching(G, matching): ...
def min_weight_matching(G, weight: str = "weight"): ...
def max_weight_matching(G, maxcardinality: bool = False, weight: str = "weight"): ...
