from _typeshed import Incomplete

def margulis_gabber_galil_graph(n, create_using: Incomplete | None = None): ...
def chordal_cycle_graph(p, create_using: Incomplete | None = None): ...
def paley_graph(p, create_using: Incomplete | None = None): ...
