from _typeshed import Incomplete

def floyd_warshall_numpy(G, nodelist: Incomplete | None = None, weight: str = "weight"): ...
def floyd_warshall_predecessor_and_distance(G, weight: str = "weight"): ...
def reconstruct_path(source, target, predecessors): ...
def floyd_warshall(G, weight: str = "weight"): ...
