from _typeshed import Incomplete

def latapy_clustering(G, nodes: Incomplete | None = None, mode: str = "dot"): ...

clustering = latapy_clustering

def average_clustering(G, nodes: Incomplete | None = None, mode: str = "dot"): ...
def robins_alexander_clustering(G): ...
